@@ -99,6 +99,7 @@ namespace mamba
         std::string custom_banner = "";
         bool is_micromamba = false;
         bool experimental = false;
+        bool debug = false;
 
         fs::path target_prefix = "";
         // Need to prevent circular imports here (otherwise using env::get())
@@ -140,6 +141,7 @@ namespace mamba
 
         bool change_ps1 = true;
 
+        bool curl_initialized = false;
         int connect_timeout_secs = 10;
         // int read_timeout_secs = 60;
         int retry_timeout = 2;  // seconds
@@ -194,9 +196,7 @@ namespace mamba
         Context(Context&&) = delete;
         Context& operator=(Context&&) = delete;
 
-#ifdef ENABLE_CONTEXT_DEBUG_PRINT
         const void debug_print();
-#endif
 
     private:
         Context();
